# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RenamableField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'internal_name': 'str',
        'display_name': 'str',
        'visible': 'bool'
    }

    attribute_map = {
        'internal_name': 'internalName',
        'display_name': 'displayName',
        'visible': 'visible'
    }

    def __init__(self, internal_name=None, display_name=None, visible=None):  # noqa: E501
        """RenamableField - a model defined in OpenAPI"""  # noqa: E501

        self._internal_name = None
        self._display_name = None
        self._visible = None
        self.discriminator = None

        if internal_name is not None:
            self.internal_name = internal_name
        if display_name is not None:
            self.display_name = display_name
        if visible is not None:
            self.visible = visible

    @property
    def internal_name(self):
        """Gets the internal_name of this RenamableField.  # noqa: E501

        The calculated name of a field.  # noqa: E501

        :return: The internal_name of this RenamableField.  # noqa: E501
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """Sets the internal_name of this RenamableField.

        The calculated name of a field.  # noqa: E501

        :param internal_name: The internal_name of this RenamableField.  # noqa: E501
        :type: str
        """

        self._internal_name = internal_name

    @property
    def display_name(self):
        """Gets the display_name of this RenamableField.  # noqa: E501

        The name that a field is renamed to by the user.  # noqa: E501

        :return: The display_name of this RenamableField.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this RenamableField.

        The name that a field is renamed to by the user.  # noqa: E501

        :param display_name: The display_name of this RenamableField.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def visible(self):
        """Gets the visible of this RenamableField.  # noqa: E501

        Indicates whether this field should be visible on the table.  # noqa: E501

        :return: The visible of this RenamableField.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """Sets the visible of this RenamableField.

        Indicates whether this field should be visible on the table.  # noqa: E501

        :param visible: The visible of this RenamableField.  # noqa: E501
        :type: bool
        """

        self._visible = visible

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RenamableField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six
from influxdb_client.domain.threshold_base import ThresholdBase


class Threshold(ThresholdBase):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'level': 'CheckStatusLevel',
        'all_values': 'bool'
    }

    attribute_map = {
        'level': 'level',
        'all_values': 'allValues'
    }

    discriminator_value_class_map = {
        
    }

    def __init__(self, level=None, all_values=None):  # noqa: E501
        """Threshold - a model defined in OpenAPI"""  # noqa: E501
        ThresholdBase.__init__(self, level=level, all_values=all_values)
        self.discriminator = 'type'

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_key = self.attribute_map[self.discriminator]
        discriminator_value = data[discriminator_key]
        return self.discriminator_value_class_map.get(discriminator_value)

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Threshold):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
